ChatSDKContext class

Available extensions

Properties

cachedMap ↔ Map<String, dynamic>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences ↔ SharedPreferences
getter/setter pair

Methods

addConversationMute(Map<String, int> map) → void

Available on ChatSDKContext, provided by the ConversationMute extension

addRequest(String userId, String? reason, [bool isGroup = false]) → bool

Available on ChatSDKContext, provided by the Request extension

clear() → void
conversationIsMute(String conversationId) → bool

Available on ChatSDKContext, provided by the ConversationMute extension

deleteConversationMute(List<String> list) → void

Available on ChatSDKContext, provided by the ConversationMute extension

isContactLoadFinished() → bool

Available on ChatSDKContext, provided by the ContactLoad extension

isConversationLoadFinished() → bool

Available on ChatSDKContext, provided by the ConversationFirstLoad extension

markAllRequestsAsRead() → void

Available on ChatSDKContext, provided by the Request extension

newRequestCount() → int

Available on ChatSDKContext, provided by the Request extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRequest(String userId, [bool isGroup = false]) → void

Available on ChatSDKContext, provided by the Request extension

removeRequests(List<String> userIds, [dynamic isGroup = false]) → void

Available on ChatSDKContext, provided by the Request extension

requestList() → List

Available on ChatSDKContext, provided by the Request extension

save() → void
setContactLoadFinished() → void

Available on ChatSDKContext, provided by the ContactLoad extension

setConversationLoadFinished() → void

Available on ChatSDKContext, provided by the ConversationFirstLoad extension

setUserId(String? userId) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ChatSDKContext
no setter