ChatUIKitInsertTools class

Constructors

ChatUIKitInsertTools()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

insertAddContactMessage(String userId) → Future<void>
insertCreateGroupMessage({required Group group, String? creator, int? timestamp}) → Future<void>
insertCreateThreadEventMessage({required ChatThreadEvent event, String? creator, int? timestamp}) → Future<void>
insertGroupDestroyMessage(String groupId) → Future<void>
insertGroupKickedMessage(String groupId) → Future<void>
insertGroupLeaveMessage(String groupId) → Future<void>
insertPinEventMessage({required String messageId, String? conversationId, String? creator, int? timestamp}) → Future<void>
insertRecallMessage({required Message recalledMessage, String? operatorId, int? timestamp}) → Message
insertUnPinEventMessage({required String messageId, String? conversationId, String? creator, int? timestamp}) → Future<void>