chat_uikit library

Classes

AlphabeticalItemModel
BlockListView
The block list view. This widget is used to display the list of blocked users.
BlockListViewController
ChangeInfoView
ChangeInfoViewArguments
ChatAreaCode
ChatBottomSheetBackground
ChatClient
~english The ChatClient class, which is the entry point of the Chat SDK. With this class, you can log in, log out, and access other functionalities such as group and chatroom. ~end
ChatCmdMessageBody
~english The command message body. ~end
ChatContact
ChatContactChangeEvent
ChatContactEventHandler
~english The contact event handler.
ChatContactManager
~english The contact manager class, which manages chat contacts such as adding, deleting, retrieving, and modifying contacts. ~end
ChatConversation
~english The conversation class, indicating a one-to-one chat, a group chat, or a conversation chat. It contains the messages that are sent and received within the conversation.
ChatCursorResult<T>
~english The ChatCursorResult class, which specifies the cursor from which to query results. When querying using this class, the SDK returns the queried instance and the cursor.
ChatCustomMessageBody
~english The custom message body. ~end
ChatDeviceInfo
~english The ChatDeviceInfo class, which contains the multi-device information. ~end
ChatDownloadCallback
~english The group shared download callback. ~end
ChatFileMessageBody
~english The base class of file messages. ~end
ChatGroup
~english The ChatGroup class, which contains the information of the chat group. ~end
ChatGroupChangeEvent
ChatGroupEventHandler
~english The group event handler.
ChatGroupInfo
~english The class that defines basic information of chat groups. ~end
ChatGroupManager
~english The group manager class, which manages group creation and deletion, user joining and exiting the group, etc. ~end
ChatGroupMessageAck
~english The class for group message read receipts.
ChatGroupOptions
~english The group options to be configured when the chat group is created. ~end
ChatGroupSharedFile
~english The ChatGroupSharedFile class, which manages the chat group shared files.
ChatImageMessageBody
~english The image message body class. ~end
ChatInputEmoji
ChatLocal
ChatLocationMessageBody
~english The location message class. ~end
ChatMessage
~english The message class.
ChatMessageBody
ChatMessageEvent
~english The message status event class. During message delivery, the message ID will be changed from a local uuid to a global unique ID that is generated by the server to uniquely identify a message on all devices using the SDK. This API should be implemented in the chat page widget to listen for message status changes. ~end
ChatMessageReaction
~english The message Reaction instance class, which has the following attributes: Reaction: The message Reaction. UserCount: The count of users that added the Reaction. UserList: The list of users that added the Reaction. isAddedBySelf: Whether the current user added this Reaction. ~end
ChatMessageReactionEvent
~english The message reaction change event class. ~end
ChatMessageSenderInfo
~english The message sender info class, which contains the user attributes of the message sender. ~end
ChatMethodKeys
ChatMultiDeviceEventHandler
~english The multi-device event handler. Listens for the callback for the current user's actions on other devices, including contact changes, group changes, and thread changes.
ChatObserver
ChatOptions
~english The ChatOptions class, which contains the settings of the Chat SDK.
ChatPageResult<T>
~english The ChatPageResult class, which is returned when calling the methods that fetch data by pagination. The SDK also returns the number of remaining pages and the data count of the next page. If the dada count is less than the count you set, there is no more data on server.
ChatPresence
~english The presence property class that contains presence properties, including the publisher's user ID and current presence state, and the platform used by the online device, as well as the presence's extension information, update time, and subscription expiration time. ~end
ChatPresenceEventHandler
~english The presence event handler.
ChatPresenceManager
~english The Manager that defines how to manage presence states. ~end
ChatPresenceStatusDetail
~english The presence details, including the platform used by the publisher's current online device and the current presence state. ~end
ChatPushConfig
~english The push configuration class, which contains the push configuration information, such as the push style. ~end
ChatPushConfigs
~english The push configuration class. ~end
ChatPushManager
~english The message push configuration options. ~end
ChatReactionInfoWidget
ChatRoomEvent
ChatRoomGift
ChatRoomGiftItem
ChatroomGiftPageController
Gift page controller, you can customize the gift page
ChatRoomGiftsView
ChatRoomGiftsWidget
ChatRoomGlobalMessageWidget
ChatRoomImageLoader
ChatRoomInputBar
ChatRoomInputBarState
ChatRoomManager
~english The chat room manager class, which manages user joining and exiting the chat room, retrieving the chat room list, and managing member privileges. The sample code for joining a chat room:
ChatRoomMembersWidget
ChatRoomMessagesWidget
ChatRoomShowGiftView
ChatRoomTextEditingController
ChatRoomUIKitAvatar
ChatRoomUIKitKey
ChatRoomUIKitMemberListTitle
ChatSDKEventsObserver
ChatSDKService
ChatSilentModeParam
~english Offline push Settings parameter entity class. ~end
ChatSilentModeResult
~english Offline push DND result class. ~end
ChatSilentModeTime
~english For offline push DND time class. ~end
ChatStreamChunk
~english The stream message chunk. ~end
ChatTextMessageBody
~english The text message class. ~end
ChatThreadManager
~english The chat thread manager class. ~end
ChatTranslateLanguage
~english The translation language class, which contains the information of the translation languages. ~end
ChatUIKit
ChatUIKitAlphabeticalListViewItem
ChatUIKitAlphabeticalWidget
ChatUIKitAlphabetSortHelper
Contact alphabet sorting, if there is Chinese, you can redefine the first letter using ChatUIKitAlphabetSortHelper, for example:
ChatUIKitAppBar
ChatUIKitAppBarAction
ChatUIKitAppBarModel
ChatUIKitAvatar
ChatUIKitBadge
ChatUIKitBottomPanelData
ChatUIKitBottomSheet<T>
ChatUIKitButton
ChatUIKitCardBubbleWidget
ChatUIKitColor
ChatUIKitCombineBubbleWidget
ChatUIKitContactListViewItem
ChatUIKitConversationListViewItem
ChatUIKitDetailContentAction
ChatUIKitDetailsListViewItem
ChatUIKitDetailsListViewItemModel
ChatUIKitDialog<T>
ChatUIKitDialogAction<T>
ChatUIKitDialogInputContentItem
ChatUIKitDownloadController
ChatUIKitDownloadsHelperWidget
ChatUIKitEditBar
ChatUIKitEmojiData
ChatUIKitEmojiPanel
ChatUIKitEmojiRichText
ChatUIKitEventAction<T>
ChatUIKitFileBubbleWidget
ChatUIKitFileSizeTool
ChatUIKitFont
ChatUIKitGroupListViewItem
ChatUIKitImageBubbleWidget
ChatUIKitImageLoader
ChatUIKitInputBar
ChatUIKitInsertTools
ChatUikitKeyboardHeight
ChatUIKitKeyboardPanel
ChatUIKitKeyboardPanelController
ChatUIKitListItemModelBase
ChatUIKitListView
ChatUIKitListViewControllerBase
ChatUIKitListViewMoreItem
ChatUIKitLocalizations
ChatUIKitMessageBubbleWidget
ChatUIKitMessageListViewAlertItem
ChatUIKitMessageListViewMessageItem
ChatUIKitMessageReactionInfo
ChatUIKitMessageReactionsRow
ChatUIKitMessageStatusWidget
ChatUIKitMessageThreadWidget
ChatUIKitMessageViewBottomMenu
ChatUIKitNewRequestListViewItem
ChatUIKitNonsupportMessageWidget
ChatUIKitObserverBase
ChatUIKitPopupMenu
ChatUIKitPopupMenuController
ChatUIKitPopupMenuStyle
ChatUIKitPositionWidget
ChatUIKitPreviewObj
ChatUIKitProfile
ChatUIKitProfile class, used to store information about contacts or groups.
ChatUIKitProvider
用户信息提供类,用于设置用户/群组展示的名称和头像信息
ChatUIKitProviderObserver
用户信息更新观察者,当用户信息更新时,会通知所有的观察者。
ChatUIKitQuoteWidget
ChatUIkitReactionWidget
ChatUIKitReplyBar
ChatUIKitRoomMembersController
ChatUIKitRoomMembersInterface
ChatUIKitRoomMembersWidget
ChatUIKitRoomMutesController
ChatUIKitRoute
路由
ChatUIKitRouteBackModel
路由返回信息,用于标记路由返回到上一页时的变更类型和 profileId
ChatUIKitRouteNames
ChatUIKitSearchHistoryViewItem
ChatUIKitSearchListViewItem
ChatUIKitSearchWidget
ChatUIKitServiceBase
ChatUIKitSettings
ChatUIKitShadow
ChatUIKitShowImageWidget
ChatUIKitShowVideoWidget
ChatUIKitTextBubbleWidget
ChatUIKitTheme
ChatUIKitThemeImpl
ChatUIKitThemeMixin
ChatUIKitTimeFormatter
ChatUIKitTimeTool
ChatUIKitURLHelper
ChatUIKitVideoBubbleWidget
ChatUIKitViewArguments
ChatUIKitViewObserver
ChatUIKitVoiceBubbleWidget
ChatUserInfo
~english The ChatUserInfo class, which contains the user attributes, such as the nickname, description, and avatar. ~end
ChatUserInfoChangeEvent
ChatUserInfoEventHandler
~english The user info event handler.
ChatUserInfoManager
~english The user attribute manager class, which gets and sets the user attributes. ~end
ChatVideoMessageBody
~english The video message body class. ~end
ChatVoiceMessageBody
~english The voice message body class. ~end
ChatVoiceParam
~english The voice file parameter class, which describes the format of the voice file to be converted to text. ~end
ConnectObserver
ContactDetailsView
ContactDetailsViewArguments
ContactItemModel
ContactListView
The contact list view. This widget is used to display the list of contacts.
ContactListViewController
联系人列表控制器
ContactObserver
ContactsView
ContactsViewArguments
ConversationFetchOptions
~english The conversation filter class. ~end
ConversationItemModel
ConversationListView
The conversation list view. This widget is used to display the list of conversations.
ConversationListViewController
会话列表控制器
ConversationsView
ConversationsViewArguments
会话列表构建参数
CreateGroupInfo
CreateGroupView
CreateGroupViewArguments
CurrentUserInfoView
CurrentUserInfoViewArguments
CustomTextEditingController
EmojiIndex
EmojiMapping
ExtSettings
FetchMessageOptions
~english The parameter configuration class for pulling historical messages from the server. ~end
ForwardMessageSelectView
ForwardMessageSelectViewArguments
ForwardMessagesView
ForwardMessagesViewArguments
GiftItem
GiftReceiveItemWidget
GiftReceiveModel
GroupAddMembersView
GroupAddMembersViewArguments
GroupChangeOwnerView
GroupChangeOwnerViewArguments
GroupDeleteMembersView
GroupDeleteMembersViewArguments
GroupDetailsView
GroupDetailsViewArguments
GroupItemModel
GroupListView
The group list view. This widget is used to display the list of groups.
GroupListViewController
GroupMemberInfo
~english The group member info class, which contains the group member information. ~end
GroupMemberListView
The group member list view. This widget is used to display the list of group members.
GroupMemberListViewController
GroupMembersView
GroupMembersViewArguments
GroupMentionView
GroupMentionViewArguments
GroupObserver
GroupsView
GroupsViewArguments
LoginExtensionInfo
MentionAllItem
MentionModel
MessageAlertAction
MessageCallBackManager
MessageListView
The list view of the message. This widget is used to display the list of messages.
MessageModel
MessageObserver
MessagePinInfo
~english The message pinning information. ~end
MessageSearchOptions
MessagesView
消息页面
MessagesViewArguments
MessagesViewController
消息列表控制器
MultiObserver
NewRequestDetailsView
NewRequestDetailsViewArguments
NewRequestItemModel
NewRequestListViewController
NewRequestsListView
The new requests list view. This widget is used to display the list of new requests.
NewRequestsView
NewRequestsViewArguments
PinListItem
PinListItemModel
PinMessageListView
The pin message list view.
PinMessageListViewController
PresenceObserver
QuoteModel
ReactionOperation
~english Reaction operation. ~end
RecallMessageInfo
RecordBar
RecordBarController
RecordBarState
RecordResultData
ReportMessageView
ReportMessageViewArguments
RoomGiftMessageListItem
RoomInputBarController
RoomMessageListItem
RoomMessageListItemManager
RoomObserver
RoomTextMessageListItem
RoomUserJoinMessageListItem
SearchGroupMembersView
SearchGroupMembersViewArguments
SearchHistoryView
SearchHistoryViewArguments
SearchNotification
SearchView
SearchViewArguments
SelectContactView
SelectContactViewArguments
SelectionControls
ShareUserData
ShowImageView
ShowImageViewArguments
ShowVideoView
ShowVideoViewArguments
ThreadMembersView
ThreadMembersViewArguments
ThreadMembersViewController
ThreadMessageListView
The thread message list view. This widget is used to display the list of thread messages.
ThreadMessagesView
ThreadMessagesViewArguments
ThreadMessagesViewController
ThreadObserver
ThreadsView
ThreadsViewArguments
TimeTool
UIKitHSLColor
UserData

Enums

ChatConversationType
~english The conversation types. ~end
ChatGroupPermissionType
~english The group roles. ~end
ChatGroupStyle
~english The group types. ~end
ChatMultiDevicesEvent
~english Multi-device event types.
ChatPushRemindType
~english The push notification modes. ~end
ChatRecordEncodeType
ChatRoomMessagePriority
~english Chat room message priorities. ~end
ChatRoomPermissionType
~english The chat room roles. ~end
ChatSDKEvent
ChatSearchDirection
~english The message search directions. ~end
ChatSilentModeParamType
~english The offline push settings. ~end
ChatStreamStatus
~english The stream message chunk status. ~end
ChatType
~english The chat types.
ChatUIKitActionType
ChatUIKitButtonType
ChatUIKitDetailsListViewItemModelType
ChatUIKitDialogActionType
ChatUIKitDialogRectangleType
ChatUIKitEvent
Chat UI Kit Action Events
ChatUIKitEventActionType
ChatUIKitFontSize
ChatUIKitKeyboardPanelType
ChatUIKitListViewType
ChatUIKitMessageAttachmentMenuStyle
ChatUIKitMessageDownloadState
ChatUIKitMessageListViewBubbleStyle
ChatUIKitMessageLongPressMenuStyle
ChatUIKitProfileType
Profile 类型,用于区分是联系人还是群组。
ChatUIKitRouteBackType
用于标记路由 ChatUIKitRouteBackModel 类型。
ChatUIKitTimeType
用来表示当前时间是消息时间还是会话时间
ChatVoiceFormat
~english The voice file format. ~end
ConversationMarkType
~english The conversation mark types.
CornerRadius
DisplayStyle
~english The push display styles. ~end
DownloadStatus
~english The download status of the attachment file. ~end
InputType
LeaveReason
~english Leave chat room reason ~end ~chinese 离开聊天室原因 ~end
LightnessStyle
MessageAlertActionType
MessageDirection
~english The message directions.
MessagePinOperation
MessageSearchScope
~english The message search scopes. ~end
MessageStatus
~english The message sending/reception status. ~end
MessageStatusType
MessageType
~english The message types. ~end
ReactionOperate
~english Reaction operations. ~end
RecordBarRecordType
TimeType

Constants

alertContactAddKey → const String
alertCreateThreadKey → const String
alertCustomMessageKey → const String
alertDeleteThreadKey → const String
alertGroupCreateKey → const String
alertGroupDestroyKey → const String
alertGroupKickedKey → const String
alertGroupLeaveKey → const String
alertOperatorIdKey → const String
alertOperatorNameKey → const String
alertPinMessageKey → const String
alertRecalledKey → const String
alertTargetIdKey → const String
alertTargetNameKey → const String
alertTargetParentIdKey → const String
alertTimeKey → const String
alertUnPinMessageKey → const String
alertUpdateThreadKey → const String
appBarHeight → const double
arrowHeight → const double
arrowPadding → const double
arrowPosition → const double
arrowWidth → const double
borderHeight → const double
cardAvatarKey → const String
cardMessageKey → const String
cardNicknameKey → const String
cardUserIdKey → const String
contactLoadFinishedKey → const String
convLoadFinishedKey → const String
defaultLeftRightPadding → const double
hasMentionAllValue → const String
hasMentionKey → const String
hasMentionValue → const String
hasTranslatedKey → const String
isNotRecording → const int
isRecording → const int
kMenuHorizontalPadding → const double
letterHeight → const double
letterWidth → const double
mentionAllValue → const String
mentionKey → const String
movedHeight → const double
msgPreviewKey → const String
msgUserInfoKey → const String
muteMapKey → const String
originHeight → const double
packageName → const String
permissionDenied → const int
playFailed → const int
quoteKey → const String
quoteMsgIdKey → const String
quoteMsgPreviewKey → const String
quoteMsgSenderKey → const String
quoteMsgTypeKey → const String
recordFailed → const int
requestsKey → const String
rtcCallWithAgoraValue → const String
sdkEventKey → const String
tooShort → const int
totalHeight → const double
typingKey → const String
userAvatarKey → const String
userExtKey → const String
userGenderKey → const String
userGroupName → const String
userIdentifyKey → const String
userNicknameKey → const String
voiceHasReadKey → const String

Properties

bottomBarHeight double
getter/setter pair
connectionTimeout int
getter/setter pair
itemHeight double
getter/setter pair
maxImageHeight double
getter/setter pair
maxImageWidth double
getter/setter pair
maxRedirects int
getter/setter pair
observers List<ChatUIKitObserverBase>
final

Functions

convertIntToChatMultiDevicesEvent(int? i) ChatMultiDevicesEvent?
groupStyleTypeFromInt(int? type) ChatGroupStyle
groupStyleTypeToInt(ChatGroupStyle? type) int
showChatUIKitBottomSheet<T>({required BuildContext context, List<ChatUIKitEventAction<T>>? items, Color? backgroundColor, Color? barrierColor, bool enableRadius = true, String? title, TextStyle? titleStyle, Widget? titleWidget, Widget? body, String? cancelLabel, bool showCancel = true, TextStyle? cancelLabelStyle, double? height, bool isDismissible = true}) Future<T?>
showChatUIKitDialog<T>({required BuildContext context, required List<ChatUIKitDialogAction<T>> actionItems, String? content, String? title, List<ChatUIKitDialogInputContentItem>? inputItems, TextStyle? hiddenStyle, double? leftRightPadding, Color barrierColor = Colors.black54, bool barrierDismissible = true, ChatUIKitDialogRectangleType? borderType}) Future<T?>
showChatUIKitRecordBar<T>({required BuildContext context, RecordBarController? controller, RecordBarOnRecord? onRecordTypeChanged, Color? backgroundColor, Color? barrierColor, int maxDuration = 60, int minDuration = 1}) Future<RecordResultData?>
showRoomGiftsView(BuildContext context, {required List<ChatroomGiftPageController> giftControllers}) Future<ChatRoomGift?>
showRoomMembersView(BuildContext context, {required String roomId, required List<ChatUIKitRoomMembersInterface> membersControllers, String? ownerId}) Future<void>

Typedefs

AlphabetSortHandler = String? Function(String? groupId, String userId, String showName)
ChatError = EMError
ChatEventHandler = EMChatEventHandler
ChatManager = EMChatManager
ChatRoom = EMChatRoom
ChatRoomEventHandler = EMChatRoomEventHandler
ChatRoomShowGiftItemBuilder = Widget? Function(String senderId, ChatRoomGift gift, ChatUIKitProfile? user)
ChatRoomUIKitMembersListItemBuilder = Widget? Function(BuildContext context, ChatUIKitProfile profile, VoidCallback? onMoreAction)
ChatThread = EMChatThread
ChatThreadEvent = EMChatThreadEvent
ChatThreadEventHandler = EMChatThreadEventHandler
ChatThreadOperation = EMChatThreadOperation
ChatUIKitActionItemOnTap = void Function(BuildContext context)
ChatUIKitAppBarActionsBuilder = List<ChatUIKitAppBarAction>? Function(BuildContext context, List<ChatUIKitAppBarAction>? defaultList)
用于在 appBar 上添加事件,会返回默认的列表,需要你调整后返回来,返回来的数据会用于菜单显示。
ChatUIKitContactItemBuilder = Widget? Function(BuildContext context, ContactItemModel model)
联系人列表 item 构建器,需要返回一个 widget,如果返回 null 将会使用默认的 item。 返回后会用于列表显示。
ChatUIKitDetailContentActionsBuilder = List<ChatUIKitDetailContentAction>? Function(BuildContext context, List<ChatUIKitDetailContentAction>? defaultList)
用于在详情页添加主要按钮事件,比如联系人详情,群组详情中添加音视频呼叫。会返回一个默认的列表,需要你调整后返回来,返回来的数据会用于菜单显示。
ChatUIKitDetailItemBuilder = List<ChatUIKitDetailsListViewItemModel> Function(BuildContext context, ChatUIKitProfile? profile, List<ChatUIKitDetailsListViewItemModel> defaultItems)
用于在联系人详情页添加 list item,会返回默认的列表,需要你调整后返回来,返回来的数据会用于菜单显示。
ChatUIKitDownloadBuilder = Widget Function(BuildContext context, String? path, String? name, ChatUIKitMessageDownloadState state, int progress)
ChatUIKitDownloadResult = void Function(Message message, String? path, ChatError? error)
ChatUIKitGroupItemBuilder = Widget Function(BuildContext context, GroupItemModel model)
群列表 item 构建器,需要返回一个 widget,如果返回 null 将会使用默认的 item。 返回后会用于列表显示。
ChatUIKitListItemBuilder = Widget? Function(BuildContext context, ChatUIKitListItemModelBase model)
ChatUIKitMoreActionsBuilder<T> = List<ChatUIKitEventAction<T>> Function(BuildContext context, List<ChatUIKitEventAction<T>> actions)
appBar 点击更多按钮时会弹出 bottom sheet, 会返回默认的列表,需要你调整后返回来,返回来的数据会用于 bottom sheet 显示。
ChatUIKitNewRequestItemBuilder = Widget Function(BuildContext context, NewRequestItemModel model)
ChatUIKitPositionWidgetHandler = void Function(Rect rect)
ChatUIKitProviderProfileHandler = List<ChatUIKitProfile>? Function(List<ChatUIKitProfile> profiles, [String? belongId])
用户信息回调,入参为需要提供信息的 profile 列表,返回值为提供信息后的 profile 列表,如果返回值为空,当再次需要展示是仍会回调。
ChatUIKitWidgetBuilder = Widget Function(BuildContext context, Object? arguments)
Client = EMClient
CmdMessageBody = EMCmdMessageBody
CombineMessageBody = EMCombineMessageBody
ConnectionEventHandler = EMConnectionEventHandler
Contact = EMContact
ContactEventHandler = EMContactEventHandler
ContactListViewShowHandler = List<ContactItemModel> Function(List<ContactItemModel> contacts)
通讯录列表展示前回调,会将当前的通讯录列表传递过来,你需要调整后返回来,返回来的数据会用于列表显示。
Conversation = EMConversation
ConversationItemBuilder = Widget? Function(BuildContext context, ConversationItemModel model)
ConversationListViewShowHandler = List<ConversationItemModel> Function(List<ConversationItemModel> conversations)
会话列表展示前回调,会将当前的会话列表传递过来,你需要调整后返回来,返回来的数据会用于列表显示。
ConversationsViewItemLongPressHandler = List<ChatUIKitEventAction>? Function(BuildContext context, ConversationItemModel model, List<ChatUIKitEventAction> defaultActions)
用户会话列表长按事件,会返回默认的列表,需要你调整后返回来,返回来的数据会用于 bottom sheet 显示。
ConversationType = EMConversationType
CreateGroupHandler = Future<CreateGroupInfo?> Function(BuildContext context, List<ChatUIKitProfile> selectedProfiles)
创建群组拦截器,当在创建群组页面点击创建后回调给你当前选择的用户,你需要返回一个 CreateGroupInfo 对象,如果返回 null 将会取消创建。
CursorResult<T> = EMCursorResult<T>
CursorResultCallback = Object Function(dynamic obj)
CustomMessageBody = EMCustomMessageBody
EMChatEventHandler = ChatEventHandler
EMChatManager = ChatManager
EMChatRoom = ChatRoom
EMChatRoomEvent = ChatRoomEvent
EMChatRoomEventHandler = ChatRoomEventHandler
EMChatRoomManager = ChatRoomManager
EMChatRoomPermissionType = ChatRoomPermissionType
EMChatThread = ChatThread
EMChatThreadEvent = ChatThreadEvent
EMChatThreadEventHandler = ChatThreadEventHandler
EMChatThreadManager = ChatThreadManager
EMChatThreadOperation = ChatThreadOperation
EMClient = ChatClient
EMCmdMessageBody = ChatCmdMessageBody
EMCombineMessageBody = CombineMessageBody
EMConnectionEventHandler = ConnectionEventHandler
EMContact = ChatContact
EMContactChangeEvent = ChatContactChangeEvent
EMContactEventHandler = ChatContactEventHandler
EMContactManager = ChatContactManager
EMConversation = ChatConversation
EMConversationType = ChatConversationType
EMCursorResult<T> = ChatCursorResult<T>
EMCustomMessageBody = ChatCustomMessageBody
EMDeviceInfo = ChatDeviceInfo
EMDownloadCallback = ChatDownloadCallback
EMError = ChatError
EMFileMessageBody = ChatFileMessageBody
EMGroup = ChatGroup
EMGroupChangeEvent = ChatGroupChangeEvent
EMGroupEventHandler = ChatGroupEventHandler
EMGroupInfo = ChatGroupInfo
EMGroupManager = ChatGroupManager
EMGroupMessageAck = ChatGroupMessageAck
EMGroupOptions = ChatGroupOptions
EMGroupPermissionType = ChatGroupPermissionType
EMGroupSharedFile = ChatGroupSharedFile
EMGroupStyle = ChatGroupStyle
EMImageMessageBody = ChatImageMessageBody
EMLocationMessageBody = ChatLocationMessageBody
EMMessage = ChatMessage
EMMessageBody = ChatMessageBody
EMMessageReaction = ChatMessageReaction
EMMessageReactionEvent = ChatMessageReactionEvent
EMMessageSenderInfo = ChatMessageSenderInfo
EMMultiDeviceEventHandler = ChatMultiDeviceEventHandler
EMMultiDevicesEvent = ChatMultiDevicesEvent
EMOptions = ChatOptions
EMPageResult<T> = ChatPageResult<T>
EMPresence = ChatPresence
EMPresenceEventHandler = ChatPresenceEventHandler
EMPresenceManager = ChatPresenceManager
EMPresenceStatusDetail = ChatPresenceStatusDetail
EMPushConfig = ChatPushConfig
EMPushConfigs = ChatPushConfigs
EMPushManager = ChatPushManager
EMSearchDirection = ChatSearchDirection
EMStreamChunk = ChatStreamChunk
EMStreamStatus = ChatStreamStatus
EMTextMessageBody = ChatTextMessageBody
EMTranslateLanguage = ChatTranslateLanguage
EMUserInfo = ChatUserInfo
EMUserInfoChangeEvent = ChatUserInfoChangeEvent
EMUserInfoEventHandler = ChatUserInfoEventHandler
EMUserInfoManager = ChatUserInfoManager
EMVideoMessageBody = ChatVideoMessageBody
EMVoiceFormat = ChatVoiceFormat
EMVoiceMessageBody = ChatVoiceMessageBody
EMVoiceParam = ChatVoiceParam
FileMessageBody = EMFileMessageBody
Group = EMGroup
GroupCreateCallback = void Function(Group? group, ChatError? error)
创建群组后的回调
GroupEventHandler = EMGroupEventHandler
GroupInfo = EMGroupInfo
GroupMessageAck = EMGroupMessageAck
GroupOptions = EMGroupOptions
GroupPermissionType = EMGroupPermissionType
GroupSharedFile = EMGroupSharedFile
GroupStyle = EMGroupStyle
ImageMessageBody = EMImageMessageBody
KeyboardHeightCallback = void Function(double height, double safeArea)
ListViewBuilder = Widget Function(BuildContext context, List<ChatUIKitListItemModelBase> list)
ListViewSearchBuilder = Widget Function(BuildContext context, String? searchKeyword, List<ChatUIKitListItemModelBase> list)
LocationMessageBody = EMLocationMessageBody
Message = EMMessage
MessageEvent = ChatMessageEvent
MessageItemAlertBuilder = Widget? Function(BuildContext context, Widget? child, MessageModel model)
提示信息builder
MessageItemBubbleBuilder = Widget? Function(BuildContext context, Widget child, MessageModel model)
消息气泡构建器,需要返回一个 widget,如果返回 null 将会使用默认的气泡。 返回后会用于列表显示。其中 child 是气泡内部的内容。
MessageItemBuilder = Widget? Function(BuildContext context, MessageModel model)
MessageItemGlobalPositionTapHandler = bool? Function(BuildContext context, MessageModel model, Rect rect)
MessageItemShowHandler = bool Function(MessageModel model)
消息列表 item 元素是否展示,返回 true 表示展示,false 表示不展示。
MessageItemTapHandler = bool? Function(BuildContext context, MessageModel model)
消息列表 item 点击事件,返回 true 表示消费事件,false 或 null 表示不消费事件,事件将会继续传递。
MessageReaction = EMMessageReaction
MessageReactionEvent = EMMessageReactionEvent
MessageReactionItemTapHandler = bool? Function(BuildContext context, MessageModel model, MessageReaction reaction)
MessagesViewItemLongPressPositionHandler = List<ChatUIKitEventAction>? Function(BuildContext context, MessageModel model, Rect rect, List<ChatUIKitEventAction> defaultActions)
消息列表 item 长按事件,会返回默认的列表,需要你调整后返回来,返回来的数据会用于 bottom sheet 显示。
MessagesViewMorePressHandler = List<ChatUIKitEventAction>? Function(BuildContext context, List<ChatUIKitEventAction> defaultActions)
消息页 输入框 更多按钮点击事件,会返回默认的列表,需要你调整后返回来,返回来的数据会用于 bottom sheet 显示。
MultiDeviceEventHandler = EMMultiDeviceEventHandler
MultiDevicesEvent = EMMultiDevicesEvent
Options = EMOptions
PageResult<T> = EMPageResult<T>
PageResultCallback = Object Function(dynamic obj)
Presence = EMPresence
PresenceEventHandler = EMPresenceEventHandler
PushConfigs = EMPushConfigs
RecordBarOnRecord = void Function(RecordBarRecordType type)
RecordBarOnRecordFinished = void Function(RecordResultData data)
RoomEventHandler = EMChatRoomEventHandler
SearchDirection = EMSearchDirection
TextMessageBody = EMTextMessageBody
TimeFormatterHandler = String? Function(BuildContext context, ChatUIKitTimeType type, int time)
时间格式化
TranslateLanguage = EMTranslateLanguage
UserInfo = EMUserInfo
VideoMessageBody = EMVideoMessageBody
VoiceMessageBody = EMVoiceMessageBody

Exceptions / Errors

RecordError