ChatDeviceInfo class

~english The ChatDeviceInfo class, which contains the multi-device information. ~end

~chinese 多设备登录信息类。 ~end

Constructors

ChatDeviceInfo(String? resource, String? deviceUUID, String? deviceName)
ChatDeviceInfo.fromJson(Map map)
factory

Properties

deviceName → String?
~english The device type. For example: "Pixel 6 Pro". ~end
final
deviceUUID → String?
~english The UUID of the device. ~end
final
hashCode → int
The hash code for this object.
no setterinherited
resource → String?
~english The information of other login devices. ~end
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited