ChatGroup class

~english The ChatGroup class, which contains the information of the chat group. ~end

~chinese 群组信息类,包含内存中的群组相关信息。

Note 如需最新数据,需先从服务器获取:ChatGroupManager.fetchGroupInfoFromServer。 ~end

Constructors

ChatGroup({required String groupId, @Deprecated('Use [groupName] instead') String? name, String? groupName, String? avatarUrl, @Deprecated('Use [desc] instead') String? description, String? desc, String? owner, String? announcement, int? memberCount, List<String>? memberList, List<String>? adminList, List<String>? blockList, List<String>? muteList, bool? messageBlocked, bool? isAllMemberMuted, ChatGroupPermissionType? permissionType, int? maxUserCount, bool? isMemberOnly, bool? isMemberAllowToInvite, String? extension, bool isDisabled = false})
ChatGroup.fromJson(Map map)
factory

Properties

adminList → List<String>?
~english Gets the admin list of the group.
final
announcement → String?
~english The content of the group announcement. ~end
final
avatarUrl → String?
~english Gets the group avatar. ~end
final
blockList → List<String>?
~english Gets the block list of the group.
final
desc → String?
~english Gets the group description.
final
description → String?
~english Gets the group description.
final
extension → String?
~english Group detail extensions which can be in the JSON format to contain more group information. ~end
final
groupId → String
~english Gets the group ID. ~end
final
groupName → String?
~english Gets the group name.
final
hashCode → int
The hash code for this object.
no setterinherited
isAllMemberMuted → bool?
~english Gets Whether all members are muted.
final
isDisabled → bool
~english Whether the group is disabled. The default value for reading or pulling roaming messages from the database is NO ~end
final
isMemberAllowToInvite → bool?
~english Checks whether a group member is allowed to invite other users to join the group.
final
isMemberOnly → bool?
~english Checks whether users cannot join a chat group freely:
final
maxUserCount → int?
~english Gets the maximum number of group members allowed in a group. The parameter is set when the group is created.
final
memberCount → int?
~english Gets the member count of the group.
final
memberList → List<String>?
~english Gets the member list of the group.
final
messageBlocked → bool?
~english Gets whether the group message is blocked.
final
muteList → List<String>?
~english Gets the mute list of the group.
final
name → String?
~english Gets the group name.
final
owner → String?
~english Gets the user ID of the group owner.
final
permissionType → ChatGroupPermissionType?
~english Gets the current user's role in group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ChatGroupOptions?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited