ChatGroupSharedFile class

~english The ChatGroupSharedFile class, which manages the chat group shared files.

To get the information of the chat group shared file, call ChatGroupManager.fetchGroupFileListFromServer.

  List<ChatGroupSharedFile>? list = await ChatClient.getInstance.groupManager.fetchGroupFileListFromServer(groupId);

~end

~chinese 群组共享文件类。

可以通过 ChatGroupManager.fetchGroupFileListFromServer 方法获取共享文件信息,示例如下:

  List<ChatGroupSharedFile> list = await ChatClient.getInstance.groupManager.fetchGroupFileListFromServer(groupId);

~end

Constructors

ChatGroupSharedFile.fromJson(Map? map)
factory

Properties

createTime → int?
~english Gets the Unix timestamp for uploading the shared file, in milliseconds.
no setter
fileId → String?
~english Gets the shared file ID.
no setter
fileName → String?
~english Gets the shared file name.
no setter
fileOwner → String?
~english Gets the username that uploads the shared file.
no setter
fileSize → int?
~english Gets the data length of the shared file, in bytes.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited