ChatImageMessageBody class

~english The image message body class. ~end

~chinese 图片消息体类。 ~end

Inheritance

Constructors

ChatImageMessageBody({required String localPath, String? displayName, String? thumbnailLocalPath, bool sendOriginalImage = false, int? fileSize, double? width, double? height, bool isGif = false})
~english Creates an image message body with an image file.
ChatImageMessageBody.fromJson({required Map map})

Properties

bigImageDownloadStatus ↔ DownloadStatus?
~english The download status of the original (big) image.
getter/setter pair
bigImageLocalPath ↔ String?
~english The local path of the original (big) image. ~end
getter/setter pair
bigImageRemotePath ↔ String?
~english The URL of the original (big) image on the server.
getter/setter pair
displayName ↔ String?
~english The attachment name. ~end
getter/setter pairinherited
fileSize ↔ int?
~english The size of the attachment in bytes. ~end
getter/setter pairinherited
fileStatus ↔ DownloadStatus
~english The download status of the attachment. ~end
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
~english The image height in pixels. ~end
getter/setter pair
isGif ↔ bool
~english ~end ~chinese ~end
getter/setter pair
localPath ↔ String
~english The local path of the attachment. ~end
latefinalinherited
remotePath ↔ String?
~english The attachment path in the server. ~end
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
~english The token used to get the attachment. ~end
getter/setter pairinherited
sendOriginalImage ↔ bool
~english Whether to send the original image.
getter/setter pair
thumbnailLocalPath ↔ String?
~english The local path or the URI (a string) of the thumbnail. ~end
getter/setter pair
thumbnailRemotePath ↔ String?
~english The URL of the thumbnail on the server. ~end
getter/setter pair
thumbnailSecret ↔ String?
~english The secret to access the thumbnail. A secret is required for verification for thumbnail download. ~end
getter/setter pair
thumbnailStatus ↔ DownloadStatus
~english The download status of the thumbnail. ~end
getter/setter pair
type ↔ MessageType
~english Gets the chat message type. ~end
getter/setter pairinherited
width ↔ double?
~english The image width in pixels. ~end
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited