ChatMessage class

~english The message class.

The sample code for constructing a text message to send is as follows.

  ChatMessage msg = ChatMessage.createTxtSendMessage(
     username: "user1",
     content: "hello",
   );

~end

~chinese 消息对象类。

创建一条待发送的文本消息示例代码如下:

  ChatMessage msg = ChatMessage.createTxtSendMessage(
     targetId: "user1",
     content: "hello",
   );

~end

Available extensions

Constructors

ChatMessage.createCmdSendMessage({required String targetId, required dynamic action, bool deliverOnlineOnly = false, ChatType chatType = ChatType.Chat})
~english Creates a command message for sending.
ChatMessage.createCombineSendMessage({required String targetId, String? title, String? summary, String? compatibleText, required List<String> msgIds, ChatType chatType = ChatType.Chat})
~english Creates a combined message for sending.
ChatMessage.createCustomSendMessage({required String targetId, required String event, Map<String, String>? params, ChatType chatType = ChatType.Chat})
~english Creates a custom message for sending.
ChatMessage.createFileSendMessage({required String targetId, required String filePath, String? displayName, int? fileSize, ChatType chatType = ChatType.Chat})
~english Creates a file message for sending.
ChatMessage.createImageSendMessage({required String targetId, required String filePath, String? displayName, String? thumbnailLocalPath, bool sendOriginalImage = false, bool isGif = false, int? fileSize, double? width, double? height, ChatType chatType = ChatType.Chat})
~english Creates an image message for sending.
ChatMessage.createLocationSendMessage({required String targetId, required double latitude, required double longitude, String? address, String? buildingName, ChatType chatType = ChatType.Chat})
~english Creates a location message for sending.
ChatMessage.createReceiveMessage({required ChatMessageBody body, ChatType chatType = ChatType.Chat})
~english Creates a received message instance.
ChatMessage.createSendMessage({required ChatMessageBody body, String? to, ChatType chatType = ChatType.Chat})
~english Creates a message instance for sending.
ChatMessage.createTxtSendMessage({required String targetId, required String content, List<String>? targetLanguages, ChatType chatType = ChatType.Chat})
~english Creates a text message for sending.
ChatMessage.createVideoSendMessage({required String targetId, required String filePath, String? displayName, int duration = 0, int? fileSize, String? thumbnailLocalPath, double? width, double? height, ChatType chatType = ChatType.Chat})
~english Creates a video message instance for sending.
ChatMessage.createVoiceSendMessage({required String targetId, required String filePath, int duration = 0, int? fileSize, String? displayName, ChatType chatType = ChatType.Chat})
~english Creates a voice message for sending.
ChatMessage.fromJson(Map<String, dynamic> map)
factory

Properties

attributes ↔ Map<String, dynamic>?
~english Message's extension attribute. ~end
getter/setter pair
avatarUrl → String?

Available on Message, provided by the MessageHelper extension

no setter
body ↔ ChatMessageBody
~english Message body. See ChatMessageBody. ~end
getter/setter pair
bodyType → MessageType

Available on Message, provided by the MessageHelper extension

no setter
cardUserAvatar → String?

Available on Message, provided by the MessageHelper extension

no setter
cardUserId → String?

Available on Message, provided by the MessageHelper extension

no setter
cardUserNickname → String?

Available on Message, provided by the MessageHelper extension

no setter
chatroomMessagePriority ← ChatRoomMessagePriority
~english Sets the priority of chat room messages. param priority The priority of chat room messages. The default value is Normal, indicating the normal priority. For details, seeChatRoomMessagePriority. ~end
no getter
chatType ↔ ChatType
~english The enumeration of chat types.
getter/setter pair
conversationId ↔ String?
~english The conversation ID. ~end
getter/setter pair
customBodyParams → Map<String, String>?

Available on Message, provided by the ChatUIKitMessage extension

no setter
deliverOnlineOnly ↔ bool
~english Whether the message is delivered only when the recipient(s) is/are online:
getter/setter pair
direction ↔ MessageDirection
~english The message direction. See MessageDirection. ~end
getter/setter pair
displayName → String?

Available on Message, provided by the MessageHelper extension

no setter
duration → int

Available on Message, provided by the MessageHelper extension

no setter
fileSize → int

Available on Message, provided by the MessageHelper extension

no setter
fileSizeStr → String

Available on Message, provided by the MessageHelper extension

no setter
from ↔ String?
~english The user ID of the message sender. ~end
getter/setter pair
fromProfile → ChatUIKitProfile

Available on Message, provided by the MessageHelper extension

no setter
getQuote → QuoteModel?

Available on Message, provided by the MessageHelper extension

no setter
hasDeliverAck ↔ bool
~english Whether the recipient has received the message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasMention → String?

Available on Message, provided by the MessageHelper extension

no setter
hasRead ↔ bool
~english Whether the message is read.
getter/setter pair
hasReadAck ↔ bool
~english Whether the recipient has read the message.
getter/setter pair
hasTranslate → bool

Available on Message, provided by the MessageHelper extension

no setter
height → double

Available on Message, provided by the MessageHelper extension

no setter
isAlertCustomMessage → bool

Available on Message, provided by the MessageHelper extension

no setter
isBroadcast ↔ bool
~english Whether it is a global broadcast message for all chat rooms in an app. ~end
latefinal
isCardMessage → bool

Available on Message, provided by the MessageHelper extension

no setter
isChatRoomGift → bool

Available on Message, provided by the ChatRoomMessage extension

no setter
isChatRoomGiftNotify → bool

Available on Message, provided by the ChatRoomMessage extension

no setter
isChatRoomJoinNotify → bool

Available on Message, provided by the ChatRoomMessage extension

no setter
isChatThreadMessage ↔ bool
~english Whether the message is sent within a chat thread.
getter/setter pair
isContentReplaced ↔ bool
~english Whether the message content is replaced. It is valid after ChatOptions.useReplacedMessageContents is enabled. ~end ~chinese 消息内容是否被替换, 开启ChatOptions.useReplacedMessageContents后有效 ~end
getter/setter pair
isCreateGroupAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isCreateThreadAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isDeleteThreadAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isDestroyGroupAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isEdit → bool

Available on Message, provided by the MessageHelper extension

no setter
isGif → bool

Available on Message, provided by the MessageHelper extension

no setter
isKickedGroupAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isLeaveGroupAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isNewContactAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isPinAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isRecallAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isRtcCallWithAgora → bool

Available on Message, provided by the MessageHelper extension

no setter
isTimeMessageAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isUnPinAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
isUpdateThreadAlert → bool

Available on Message, provided by the MessageHelper extension

no setter
localPath → String?

Available on Message, provided by the MessageHelper extension

no setter
localTime ↔ int
~english The local timestamp when the message is created on the local device, in milliseconds. ~end
getter/setter pair
msgId → String
~english Gets the message ID.
no setter
needGroupAck ↔ bool
~english Whether read receipts are required for group messages.
getter/setter pair
nickname → String?

Available on Message, provided by the MessageHelper extension

no setter
onlineState ↔ bool
~english Whether the message gets delivered to an online user.
latefinal
receiverList ↔ List<String>?
~english The recipient list of a targeted message.
getter/setter pair
remotePath → String?

Available on Message, provided by the MessageHelper extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
senderInfo ↔ ChatMessageSenderInfo?
~english The user attributes of the message sender.
getter/setter pair
serverTime ↔ int
~english The timestamp when the message is received by the server. ~end
getter/setter pair
status ↔ MessageStatus
~english The message sending/reception status. See MessageStatus. ~end
getter/setter pair
streamChunk ↔ ChatStreamChunk?
~english The stream chunk of the message. Only valid for stream messages. ~end
getter/setter pair
summary → String?

Available on Message, provided by the MessageHelper extension

no setter
textContent → String

Available on Message, provided by the MessageHelper extension

no setter
thumbnailLocalPath → String?

Available on Message, provided by the MessageHelper extension

no setter
thumbnailRemotePath → String?

Available on Message, provided by the MessageHelper extension

no setter
to ↔ String?
~english The message recipient.
getter/setter pair
translateText → String

Available on Message, provided by the MessageHelper extension

no setter
voiceHasPlay → bool

Available on Message, provided by the MessageHelper extension

no setter
webhookEnv ↔ String?
~english The environment identifier for the message callback (webhook) route.
getter/setter pair
width → double

Available on Message, provided by the MessageHelper extension

no setter

Methods

addPreview(ChatUIKitPreviewObj? previewObj) → void

Available on Message, provided by the MessageHelper extension

addProfile() → void

Available on Message, provided by the MessageHelper extension

addQuote(Message message) → void

Available on Message, provided by the MessageHelper extension

addUserInfo([String? belongId]) → void

Available on Message, provided by the ChatRoomMessage extension

chatThread() → Future<ChatThread?>
~english Get an overview of the thread in the message (currently only supported by group messages)
dispose() → void
getGift() → ChatRoomGift?

Available on Message, provided by the ChatRoomMessage extension

getPreview() → ChatUIKitPreviewObj?

Available on Message, provided by the MessageHelper extension

getUserInfo() → ChatUIKitProfile?

Available on Message, provided by the ChatRoomMessage extension

groupAckCount() → Future<int>
~english Gets the number of members that have read the group message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pinInfo() → Future<MessagePinInfo?>
reactionList() → Future<List<ChatMessageReaction>>
~english Gets the Reaction list.
removePreview() → void

Available on Message, provided by the MessageHelper extension

setHasTranslate(bool hasTranslate) → void

Available on Message, provided by the MessageHelper extension

setVoiceHasPlay(bool hasPlay) → void

Available on Message, provided by the MessageHelper extension

showInfo({String? customInfo}) → String

Available on Message, provided by the MessageHelper extension

showInfoTranslate(BuildContext context, {bool needShowName = false}) → String

Available on Message, provided by the MessageHelper extension

toJson() → Map<String, dynamic>
toQuote() → QuoteModel

Available on Message, provided by the MessageHelper extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited