ChatMessageBody class abstract

Constructors

ChatMessageBody({required MessageType type})
ChatMessageBody.fromJson({required Map map, required MessageType type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ MessageType
~english Gets the chat message type. ~end
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited