ChatMessageSenderInfo class

~english The message sender info class, which contains the user attributes of the message sender. ~end

~chinese 消息发送者信息类,包含消息发送者的用户属性。 ~end

Constructors

ChatMessageSenderInfo({String? userId, String? nickname, String? avatarUrl, String? remark, String? groupNameCard})
~english Creates a message sender info. ~end
ChatMessageSenderInfo.fromJson(Map map)
factory

Properties

avatarUrl → String?
~english The avatar URL of the message sender. ~end
final
groupNameCard → String?
~english The group namecard of the message sender. ~end
final
hashCode → int
The hash code for this object.
no setterinherited
nickname → String?
~english The nickname of the message sender. ~end
final
remark → String?
~english The remark of the message sender set by the current user. ~end
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
~english The user ID of the message sender. ~end
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited