ChatPushConfig class

~english The push configuration class, which contains the push configuration information, such as the push style. ~end

Constructors

ChatPushConfig()

Properties

agreePrivacyStatement ↔ bool
getter/setter pair
apnsCertName ↔ String
getter/setter pair
enableAPNS ↔ bool
getter/setter pair
enableFCM ↔ bool
getter/setter pair
enableHonorPush ↔ bool
getter/setter pair
enableHWPush ↔ bool
getter/setter pair
enableMeiZuPush ↔ bool
getter/setter pair
enableMiPush ↔ bool
getter/setter pair
enableOppoPush ↔ bool
getter/setter pair
enableVivoPush ↔ bool
getter/setter pair
fcmId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
miAppId ↔ String
getter/setter pair
miAppKey ↔ String
getter/setter pair
mzAppId ↔ String
getter/setter pair
mzAppKey ↔ String
getter/setter pair
oppoAppKey ↔ String
getter/setter pair
oppoAppSecret ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override
updateFromJson(Map<String, dynamic> json) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited