ChatPushManager class

~english The message push configuration options. ~end

~chinese 推送设置管理类。 ~end

Constructors

ChatPushManager()
~english Gets the push configurations from the server. ~end

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindDeviceToken({required String notifierName, required String deviceToken}) → Future<void>
~english Binds the push token of the device.
bindPushKitToken({required String deviceToken}) → Future<void>
~english Binds the Apple PushKit token, which is used for VoIP push notifications.
fetchConversationSilentMode({required String conversationId, required ChatConversationType type}) → Future<ChatSilentModeResult>
~english Gets the offline push settings of a conversation.
fetchPreferredNotificationLanguage() → Future<String?>
~english Gets the preferred language for push notifications.
fetchPushConfigsFromServer() → Future<ChatPushConfigs>
fetchSilentModeForAll() → Future<ChatSilentModeResult>
~english Gets the offline push settings at the app level for the current login user.
fetchSilentModeForConversations(List<ChatConversation> conversations) → Future<Map<String, ChatSilentModeResult>>
~english Gets the offline push settings of specified conversations.
getPushTemplate() → Future<String?>
~english Gets the template for offline push notifications.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeConversationSilentMode({required String conversationId, required ChatConversationType type}) → Future<void>
~english Removes the offline push notification settings for a conversation.
setConversationSilentMode({required String conversationId, required ChatConversationType type, required ChatSilentModeParam param}) → Future<void>
~english Sets the push notifications for a conversation.
setPreferredNotificationLanguage(String languageCode) → Future<void>
~english Sets the preferred language for push notifications.
setPushTemplate(String pushTemplateName) → Future<void>
~english Sets the template for offline push notifications.
setSilentModeForAll({required ChatSilentModeParam param}) → Future<void>
~english Sets the offline push settings at the app level for the current login user.
syncConversationsSilentMode() → Future<void>
~english Get all conversations mute info from server.
toString() → String
A string representation of this object.
inherited
unbindPushKitToken() → Future<void>
~english Unbinds the Apple PushKit token bound by bindPushKitToken.
updateAPNsDeviceToken(String token) → Future<void>
~english Updates the APNs push token.
updateFCMPushToken(String token) → Future<void>
~english Updates the FCM push token,
updateHMSPushToken(String token) → Future<void>
~english Updates the HMS push token.
updatePushDisplayStyle(DisplayStyle displayStyle) → Future<void>
~english Updates the push message display style. The default value is DisplayStyle.Simple.
updatePushNickname(String nickname) → Future<void>
~english Updates the push display nickname of the current user.

Operators

operator ==(Object other) → bool
The equality operator.
inherited