ChatSearchServerMessageResult class

~english The result of a message searched from the server.

This class is returned by ChatManager.searchMessagesFromServer. ~end

~chinese 服务端消息搜索的结果类。

该类由 ChatManager.searchMessagesFromServer 返回。 ~end

Constructors

ChatSearchServerMessageResult.fromJson(Map map)
factory

Properties

attributes ↔ Map<String, dynamic>?
~english The extension attributes of the message. ~end
getter/setter pair
body ↔ ChatMessageBody?
~english The message body. ~end
getter/setter pair
chatType ↔ ChatType
~english The chat type. See ChatType. ~end
getter/setter pair
convId ↔ String
~english The conversation ID. ~end
getter/setter pair
from ↔ String
~english The user ID of the message sender. ~end
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highlightTexts ↔ List<String>?
~english The highlighted texts matched by the search keywords. ~end
getter/setter pair
msgId ↔ String
~english The message ID. ~end
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ int
~english The message timestamp, in milliseconds. ~end
getter/setter pair
to ↔ String
~english The message recipient.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited