ChatStreamChunk class

~english The stream message chunk. ~end

~chinese 流式消息块。 ~end

Constructors

ChatStreamChunk.fromJson(Map<String, dynamic> map)
~english Creates a stream chunk from a JSON map.
factory

Properties

chunk → String
~english The text content of the stream chunk. ~end
final
customType → String?
~english The custom type. ~end
final
errorCode → int
~english The error code. ~end
final
finishReason → int
~english The finish reason. ~end
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChatStreamStatus
~english The stream status. ~end
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited