ChatUIKitBottomPanelData class

Constructors

ChatUIKitBottomPanelData({Widget? child, required double height, required ChatUIKitKeyboardPanelType panelType, bool showCursor = false})
const

Properties

child → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
panelType → ChatUIKitKeyboardPanelType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCursor → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited