ChatUIKitKeyboardPanelController class

Constructors

ChatUIKitKeyboardPanelController({TextEditingController? inputTextEditingController})

Properties

currentPanelType → ChatUIKitKeyboardPanelType
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreFocus ↔ bool
getter/setter pair
inputPanelFocusNode → FocusNode
no setter
inputTextEditingController → TextEditingController
no setter
readOnly ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter

Methods

clearText() → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchPanel(ChatUIKitKeyboardPanelType panelType, {Duration? duration}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited