ChatUIKitShadow class

Constructors

ChatUIKitShadow()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

darkLarge ↔ List<BoxShadow>
getter/setter pair
darkMiddle ↔ List<BoxShadow>
getter/setter pair
darkSmall ↔ List<BoxShadow>
getter/setter pair
lightLarge ↔ List<BoxShadow>
getter/setter pair
lightMiddle ↔ List<BoxShadow>
getter/setter pair
lightSmall ↔ List<BoxShadow>
getter/setter pair