ChatUserInfoEventHandler constructor

ChatUserInfoEventHandler({
  1. void onSelfUserInfoUpdate(
    1. ChatUserInfo userInfo
    )?,
  2. void onUserInfoUpdate(
    1. List<ChatUserInfo> userInfos
    )?,
})

~english The user info event handler.

Param onSelfUserInfoUpdate The user attributes of the current user are updated.

Param onUserInfoUpdate The user attributes of subscribed users are updated. ~end

~chinese 用户属性事件监听。

Param onSelfUserInfoUpdate 当前用户的用户属性更新回调。

Param onUserInfoUpdate 被订阅用户的用户属性更新回调。 ~end

Implementation

ChatUserInfoEventHandler({
  this.onSelfUserInfoUpdate,
  this.onUserInfoUpdate,
});