ChatUserInfoManager class

~english The user attribute manager class, which gets and sets the user attributes. ~end

~chinese 用户属性类,用于获取和更新用户属性。 ~end

Constructors

ChatUserInfoManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventHandler(String identifier, ChatUserInfoEventHandler handler) → void
~english Adds the user info event handler. After calling this method, you can handle new user info events when they arrive.
clearEventHandlers() → void
~english Clear all user info event handlers. ~end
clearUserInfoCache() → void
~english clear all userInfo cache. ~end
fetchOwnInfo({int expireTime = 0}) Future<ChatUserInfo?>
~english Gets the current user's attributes from the server.
fetchSubscribedUsers() Future<List<ChatUserInfo>>
~english Gets the list of users whose user attributes are subscribed by the current user.
fetchUserInfoById(List<String> userIds, {int expireTime = 0}) Future<Map<String, ChatUserInfo>>
~english Gets user attributes of the specified users.
getEventHandler(String identifier) ChatUserInfoEventHandler?
~english Get the user info event handler.
getLocalUserInfoByIds(List<String> userIds) Future<Map<String, ChatUserInfo>>
~english Gets the user attributes of the specified users from the local database.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventHandler(String identifier) → void
~english Remove the user info event handler.
subscribeUsersInfo(List<String> userIds) Future<void>
~english Subscribes to the user attributes of the specified users.
toString() String
A string representation of this object.
inherited
unsubscribeUsersInfo(List<String> userIds) Future<void>
~english Unsubscribes from the user attributes of the specified users.
updateUserInfo({String? nickname, String? avatarUrl, String? mail, String? phone, int? gender, String? sign, String? birth, String? ext}) Future<ChatUserInfo>
~english Modifies the user attributes of the current user.

Operators

operator ==(Object other) bool
The equality operator.
inherited