text property
~english The text converted from the voice message.
This field is delivered by the server and is valid only for received messages. ~end
~chinese 语音消息转换后的文本内容。
该字段为服务器下发字段,仅对收到的消息有效。 ~end
Implementation
String? text;
~english The text converted from the voice message.
This field is delivered by the server and is valid only for received messages. ~end
~chinese 语音消息转换后的文本内容。
该字段为服务器下发字段,仅对收到的消息有效。 ~end
String? text;