requireDeliveryAck property
~english Whether to require the delivery receipt after sending a message.
true: Yes;- (Default)
false: No. ~end
~chinese /// 是否发送消息已送达回执。
true:是。- (默认)
false:否。 ~end
Implementation
final bool requireDeliveryAck;
~english Whether to require the delivery receipt after sending a message.
true: Yes;false: No.
~end~chinese /// 是否发送消息已送达回执。
true:是。false:否。
~endfinal bool requireDeliveryAck;