MessagePinInfo class

~english The message pinning information. ~end

~chinese 消息置顶信息。 ~end

Constructors

MessagePinInfo({required int pinTime, required String operatorId})
~english Constructor of MessagePinInfo.
MessagePinInfo.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatorId → String
~english The user ID of the operator that pins the message. ~end ~chinese 置顶的操作者的用户 ID。 ~end
final
pinTime → int
~english The time when the message is pinned. ~end ~chinese 置顶时间。 ~end
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited