UIKitHSLColor class

Constructors

UIKitHSLColor({required LightnessStyle light, required double hue, double alpha = 1.0, double saturation = 0.08})
const

Properties

alpha → double
final
hashCode → int
The hash code for this object.
no setterinherited
hue → double
final
light → LightnessStyle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation → double
final

Methods

getColor() → Color
lightnessDouble(LightnessStyle lightness) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited