MessagesViewController class

消息列表控制器

Inheritance
Mixed-in types
Available extensions

Constructors

MessagesViewController({required ChatUIKitProfile profile, int pageSize = 30, Message? searchedMsg, Future<Message>? willSendHandler(Message willSendMessage)?})

Properties

bottomConditions → List<BottomCondition>
final
cacheMessages ↔ List<MessageModel>
getter/setter pair
canMoveToBottomPosition ↔ bool
getter/setter pair
chatType → ChatType
no setter
conversationType ↔ ConversationType
会话类型, 不可修改,会根据 profile 自动设置。 详细参考 ConversationType
latefinal
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasNew ↔ bool
不可修改
getter/setter pair
hasSearched ↔ bool
getter/setter pair
isDisposed ↔ bool
不可修改
getter/setter pair
isMultiSelectMode ↔ bool
getter/setter pair
lastActionType ↔ MessageLastActionType
不可修改
getter/setter pair
msgModelList → List<MessageModel>
消息列表
final
pageSize → int
一次获取的消息数量,默认为 30
final
pinedMessages ↔ ValueNotifier<List<Message>>
getter/setter pair
profile ↔ ChatUIKitProfile
用户信息对象,用于设置对方信息, 详细参考 ChatUIKitProfile。如果你自己设置了 MessageListViewController 需要确保 profile 与 MessagesView 传入的 profile 一致。
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchedMsg ↔ Message?
getter/setter pair
selectedMessages ↔ List<Message>
getter/setter pair
userMap → Map<String, ChatUIKitProfile>
用户信息缓存,用于显示头像昵称, 不建议修改, 详细参考 ChatUIKitProfile
final
willSendHandler → Future<Message>? Function(Message willSendMessage)?
final

Methods

addAllCacheToList() → void
addCanMoveBottomConditions(BottomCondition condition) → void

Available on MessagesViewController, provided by the MessageListViewControllerExtension extension

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
attemptSendInputType() → void
cleanBottomConditions(BottomCondition condition) → void

Available on MessagesViewController, provided by the MessageListViewControllerExtension extension

clearMentionIfNeed() → void
clearMessages() → void
deleteMessage(String messageId) → Future<void>
deleteMessages({required List<String> messageIds}) → Future<void>
deleteSelectedMessages() → void
disableMultiSelectMode() → void
dispose() → void
Discards any resources used by the object.
override
downloadMessage(Message message) → Future<void>
editMessage(Message message, String content) → Future<void>
enableMultiSelectMode() → void
fetchItemList() → void
fetchPinnedMessages() → Future<void>
getModelId(Message message) → String
jumpToSearchedMessage(Message searchedMessage) → void
markAllMessageAsRead() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onChatThreadCreate(ChatThreadEvent event) → void
inherited
onChatThreadDestroy(ChatThreadEvent event) → void
override
onChatThreadUpdate(ChatThreadEvent event) → void
override
onCmdMessagesReceived(List<Message> messages) → void
inherited
onConversationRead(String from, String to) → void
override
onConversationsUpdate() → void
inherited
onGroupMessageRead(List<GroupMessageAck> groupMessageAcks) → void
inherited
onMessageContentChanged(Message message, String operatorId, int operationTime) → void
override
onMessagePinChanged(String messageId, String conversationId, MessagePinOperation pinOperation, MessagePinInfo pinInfo) → void
override
onMessageReactionDidChange(List<MessageReactionEvent> events) → void
override
onMessagesDelivered(List<Message> messages) → void
override
onMessageSendError(String msgId, Message msg, ChatError error) → void
override
onMessageSendProgress(String msgId, int progress) → void
inherited
onMessageSendSuccess(String msgId, Message msg) → void
override
onMessagesRead(List<Message> messages) → void
override
onMessagesRecalled(List<Message> recalled) → void
inherited
onMessagesRecalledInfo(List<RecallMessageInfo> infos, List<Message> replaces) → void
override
onMessagesReceived(List<Message> messages) → void
override
onMessageUpdate(Message newMessage, [Message? oldMessage]) → void
override
onMessageWillSend(Message msg) → void
inherited
onReadAckForGroupMessageUpdated() → void
inherited
onTyping(List<String> fromUsers) → void
inherited
onUserKickOutOfChatThread(ChatThreadEvent event) → void
inherited
pinMessage(Message message) → Future<void>
playMessage(Message message) → void
recallMessage(Message message) → Future<void>
refresh() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reportMessage({required Message message, required String tag, required String reason}) → Future<void>
resendMessage(Message message) → Future<void>
sendCardMessage(ChatUIKitProfile cardProfile) → Future<void>
sendConversationsReadAck() → Future<void>
sendFileMessage(String path, {String? name, int? fileSize}) → Future<void>
sendImageMessage(String path, {String? name, bool? isGif}) → Future<void>
sendMessage(Message message) → Future<void>
sendMessageReadAck(Message message) → void
sendTextMessage(String text, {Message? replay, dynamic mention}) → Future<void>
sendVideoMessage(String path, {String? name, double? width, double? height, int? duration}) → Future<void>
sendVoiceMessage(String path, int duration, String? displayName) → Future<void>
toString() → String
A string representation of this object.
inherited
translateMessage(Message message, {bool showTranslate = true}) → Future<void>
unpinMessage(Message message) → Future<void>
updateReaction(String messageId, String reaction, bool isAdd) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited