MessageModel class

Constructors

MessageModel({String? modelId, required Message message, List<MessageReaction>? reactions, Message? quoteMessage, ChatThread? thread, MessagePinInfo? pinInfo})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
message → Message
final
pinInfo → MessagePinInfo?
final
quoteMessage → Message?
final
reactions → List<MessageReaction>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thread → ChatThread?
final

Methods

clearPinInfo() → MessageModel
clearThread() → MessageModel
copyWith({Message? message, List<MessageReaction>? reactions, Message? quoteMessage, ChatThread? thread, MessagePinInfo? pinInfo}) → MessageModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

randomId(Message message) → String