QuoteModel class

Constructors

QuoteModel(String msgId, String msgType, String preview, String sender)
QuoteModel.fromMessage(Message message, String preview)

Properties

hashCode → int
The hash code for this object.
no setterinherited
msgId → String
final
msgType → String
final
preview → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited