GroupsView class

Inheritance

Constructors

GroupsView({GroupListViewController? controller, ChatUIKitAppBarModel? appBarModel, void onSearchTap(List<GroupItemModel> data)?, ChatUIKitGroupItemBuilder? itemBuilder, void onTap(BuildContext context, GroupItemModel model)?, void onLongPress(BuildContext context, GroupItemModel model)?, String? searchBarHideText, Widget? listViewBackground, String? loadErrorMessage, bool enableAppBar = true, String? attributes, ChatUIKitViewObserver? viewObserver, Key? key})
const
GroupsView.arguments(GroupsViewArguments arguments, {Key? key})

Properties

appBarModel → ChatUIKitAppBarModel?
final
attributes → String?
final
controller → GroupListViewController?
final
enableAppBar → bool
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → ChatUIKitGroupItemBuilder?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listViewBackground → Widget?
final
loadErrorMessage → String?
final
onLongPress → void Function(BuildContext context, GroupItemModel model)?
final
onSearchTap → void Function(List<GroupItemModel> data)?
final
onTap → void Function(BuildContext context, GroupItemModel model)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchBarHideText → String?
final
viewObserver → ChatUIKitViewObserver?
用于刷新页面的Observer
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<GroupsView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited