ChatUIKitButton class

Inheritance

Constructors

ChatUIKitButton(String text, {VoidCallback? onTap, required ChatUIKitButtonType type, FontWeight? fontWeight, double? fontSize, double radius = 0, double borderWidth = 1, Key? key})
const
ChatUIKitButton.destructive(String text, {VoidCallback? onTap, FontWeight? fontWeight, double? fontSize, double radius = 0, double borderWidth = 1, Key? key})
const
ChatUIKitButton.neutral(String text, {VoidCallback? onTap, FontWeight? fontWeight, double? fontSize, double radius = 0, double borderWidth = 1, Key? key})
const
ChatUIKitButton.primary(String text, {VoidCallback? onTap, FontWeight? fontWeight, double? fontSize, double radius = 0, double borderWidth = 1, Key? key})
const

Properties

borderWidth → double
final
fontSize → double?
final
fontWeight → FontWeight?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
type → ChatUIKitButtonType
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
destructiveBgColor(ChatUIKitTheme theme) → Color
destructiveBorderColor(ChatUIKitTheme theme) → Color
destructiveTextColor(ChatUIKitTheme theme) → Color
neutralBgColor(ChatUIKitTheme theme) → Color
neutralBorderColor(ChatUIKitTheme theme) → Color
neutralTextColor(ChatUIKitTheme theme) → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primaryBgColor(ChatUIKitTheme theme) → Color
primaryBorderColor(ChatUIKitTheme theme) → Color
primaryTextColor(ChatUIKitTheme theme) → Color
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited