webhookEnv property
~english The environment identifier for the message callback (webhook) route.
- Not set (null): The default callback route is used.
- Empty string: The message is handled as unmatched.
- A valid value: The message matches the callback route configured for the value on the server. ~end
~chinese 消息回调(webhook)路由的环境标识。
- 不设置(null):使用默认回调路由;
- 空字符串:按未匹配处理;
- 有效值:匹配服务端为该值配置的回调路由。 ~end
Implementation
String? webhookEnv;