ChatMessageSearchOption class
~english The option class for searching messages from the server.
This feature is a value-added service. To use it, you need to activate the message search service on the Console. ~end
~chinese 服务端消息搜索选项类。
该功能为增值服务,需在环信 Console 开通「消息搜索」服务后方可使用。 ~end
Constructors
-
ChatMessageSearchOption({required List<
String> keywordList, ChatKeywordListMatchType keywordMatchType = ChatKeywordListMatchType.OR, String? conversationId, List<MessageType> ? msgTypes, int? startTime, int? endTime, MessageSearchScope searchScope = MessageSearchScope.Content}) - ~english Creates a message search option.
- ChatMessageSearchOption.fromJson(Map map)
-
factory
Properties
- conversationId → String?
-
~english
The conversation ID.
final
- endTime → int?
-
~english
The end timestamp for the search, in milliseconds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keywordList
→ List<
String> -
~english
The keyword list, which can contain up to 5 keywords. Each keyword contains 1-120 characters, and all keywords together contain up to 120 characters.
~end
final
- keywordMatchType → ChatKeywordListMatchType
-
~english
The match type for the keyword list. The default value is ChatKeywordListMatchType.OR.
~end
final
-
msgTypes
→ List<
MessageType> ? -
~english
The message type list. See MessageType.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchScope → MessageSearchScope
-
~english
The message search scope. The default value is MessageSearchScope.Content.
~end
final
- startTime → int?
-
~english
The start timestamp for the search, in milliseconds.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited