conversationId property
~english The conversation ID.
- For a one-to-one chat, it is the user ID of the peer user.
- For a group chat or chat room, it is the group or chat room ID.
If it is not set, messages in all conversations are searched. ~end
~chinese 会话 ID。
- 单聊:对方用户 ID;
- 群聊或聊天室:群组或聊天室 ID。
不设置时搜索所有会话。 ~end
Implementation
final String? conversationId;