ChatUserInfoEventHandler class
~english The user info event handler.
Occurs when the user attributes of the current user or subscribed users are updated.
Adds a user info event handler:
ChatClient.getInstance.userInfoManager.addEventHandler(UNIQUE_HANDLER_ID, ChatUserInfoEventHandler());
Removes a user info event handler:
ChatClient.getInstance.userInfoManager.removeEventHandler(UNIQUE_HANDLER_ID);
~end
~chinese 用户属性事件监听。
当前用户或被订阅用户的用户属性更新时触发。
添加监听:
ChatClient.getInstance.userInfoManager.addEventHandler(UNIQUE_HANDLER_ID, ChatUserInfoEventHandler());
移除监听:
ChatClient.getInstance.userInfoManager.removeEventHandler(UNIQUE_HANDLER_ID);
~end
Constructors
-
ChatUserInfoEventHandler({void onSelfUserInfoUpdate(ChatUserInfo userInfo)?, void onUserInfoUpdate(List<
ChatUserInfo> userInfos)?}) - ~english The user info event handler.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onSelfUserInfoUpdate → void Function(ChatUserInfo userInfo)?
-
~english
Occurs when the user attributes of the current user are updated.
final
-
onUserInfoUpdate
→ void Function(List<
ChatUserInfo> userInfos)? -
~english
Occurs when the user attributes of subscribed users are updated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited